package com.ruoyi.system.service;

import com.ruoyi.system.domain.assets.CommunityAssets;

import java.util.List;

/**
 * 社区资产Service接口
 * 
 * @author boman
 * @date 2025-02-24
 */
public interface ICommunityAssetsService 
{
    /**
     * 查询社区资产
     * 
     * @param communityAssetId 社区资产主键
     * @return 社区资产
     */
    public CommunityAssets selectCommunityAssetsByCommunityAssetId(Long communityAssetId);

    /**
     * 查询社区资产列表
     * 
     * @param communityAssets 社区资产
     * @return 社区资产集合
     */
    public List<CommunityAssets> selectCommunityAssetsList(CommunityAssets communityAssets);

    /**
     * 新增社区资产
     * 
     * @param communityAssets 社区资产
     * @return 结果
     */
    public int insertCommunityAssets(CommunityAssets communityAssets);

    /**
     * 修改社区资产
     * 
     * @param communityAssets 社区资产
     * @return 结果
     */
    public int updateCommunityAssets(CommunityAssets communityAssets);

    /**
     * 批量删除社区资产
     * 
     * @param communityAssetIds 需要删除的社区资产主键集合
     * @return 结果
     */
    public int deleteCommunityAssetsByCommunityAssetIds(Long[] communityAssetIds);

    /**
     * 删除社区资产信息
     * 
     * @param communityAssetId 社区资产主键
     * @return 结果
     */
    public int deleteCommunityAssetsByCommunityAssetId(Long communityAssetId);
    /**
     * 校验资产编号的唯一性
     * @param communityAssets
     * @return
     */
    public boolean checkEquipmentNumberUnique(CommunityAssets communityAssets);
}
